/**************************************************************** 
 * Description: 
 解题思路
这道题是关于瑞士轮赛制的模拟问题。瑞士轮赛制是一种相对公平且赛程不长的比赛形式。在这道题目中，我们需要模拟 R 轮比赛，最后根据比赛结果得出第 Q 名的选手编号。
解题步骤
1、初始输入：
我们从输入中读取 N, R, Q，这里 N 是一半的选手数，R 是比赛的轮数，Q 是我们关心的最终排名。
然后读取两个数组：s（初始分数）和 w（选手的实力值）。
2、初始化选手信息：
我们用数组 a 存储选手的编号，并且最初按输入顺序排列。
按照初始分数 s 和选手编号对选手进行排序，分数高的排在前面，如果分数相同，编号小的排在前面。
3、模拟比赛：
在每一轮比赛中，我们会将选手按当前的排名进行两两对决。
使用两个数组 win 和 lose 分别记录每场比赛的胜者和败者。
根据选手的实力值 w 来决定胜负。实力值较高的选手胜出，胜者得 1 分。
4、合并胜者和败者：
比赛结束后，我们需要将 win 和 lose 数组中的选手按得分排序，合并成新的 a 数组，用于下一轮比赛。
5、重复进行 R 轮比赛：
重复步骤 3 和 4，直到进行完 R 轮比赛。
输出结果：
最终根据排名数组 a 输出第 Q 名选手的编号。
 * Author: Alex Li
 * Date: 2024-08-16 15:08:32
 * LastEditTime: 2024-08-16 15:11:13
****************************************************************/
#include<iostream> 
#include<algorithm>    
using namespace std;  

int n, r, q;  
int a[200100], win[200100], lose[200100];  
int s[200100], w[200100];   

// 比较函数，用于排序：首先比较分数，然后比较编号
bool cmp(int x, int y) {  
    if(s[x] == s[y])   
        return x < y;  // 分数相同则编号小的靠前
    return s[x] > s[y]; // 分数高的靠前
}  

// 合并函数，用于合并胜者和败者，按分数和编号排序
void merge() {  
    int i, j;  
    i = j = 1; 
    a[0] = 0;  
    while(i <= win[0] && j <= lose[0])  
        if(cmp(win[i], lose[j]))  
            a[++a[0]] = win[i++];  
        else   
            a[++a[0]] = lose[j++];  
    while(i <= win[0]) 
        a[++a[0]] = win[i++];  
    while(j <= lose[0]) 
        a[++a[0]] = lose[j++];          
}  

int main() {  
    cin >> n >> r >> q;
    n *= 2;  // 总共2N个选手
    for(int i = 1; i <= n; i++) 
        a[i] = i;  // 初始化选手编号
    for(int i = 1; i <= n; i++) 
        cin >> s[i];  // 读取初始分数
    for(int i = 1; i <= n; i++) 
        cin >> w[i];  // 读取实力值
    
    sort(a+1, a+n+1, cmp);  // 按初始分数和编号排序

    // 模拟 R 轮比赛
    for(int i = 1; i <= r; i++) {  
        win[0] = lose[0] = 0;  // 重置胜者和败者数组
        for(int j = 1; j <= n; j += 2) {  
            if(w[a[j]] > w[a[j+1]]) {  // 实力值较高的选手胜出
                s[a[j]]++;  // 胜者加1分
                win[++win[0]] = a[j];  // 加入胜者数组
                lose[++lose[0]] = a[j+1];  // 加入败者数组
            } else {  
                s[a[j+1]]++;  // 胜者加1分
                win[++win[0]] = a[j+1];  
                lose[++lose[0]] = a[j];  
            }    
        }  
        merge();  // 合并胜者和败者，形成新排名
    }  
    
    cout << a[q];  // 输出第Q名选手的编号
    return 0;  
}  
